function a=convint(N,B)
% N = numero da convertire
% B = base nuova conversione
% a = vettore del numero convertito
%
a=zeros(1,100);
k=0;
while(N~=0) & (k<=100)
   k=k+1;
   a(k)=rem(N,B);
   N=fix(N/B);
end
a=a(k:-1:1);